searchData={"items":[{"type":"module","title":"ExDateUtil.Rrule","doc":"Rrule parsing and utility functions using precompiled Rust NIF from https://github.com/fmeringdal/rust-rrule\n\n# Note:\n- All RRules must contain a DTSTART value, e.g. `DTSTART;TZID=Europe/London:20230326T000000Z`\n- All dates must be passed in RFC3339 format, e.g. `\"2023-06-19T12:00:01+01:00\"`","ref":"ExDateUtil.Rrule.html"},{"type":"function","title":"ExDateUtil.Rrule.between/4","doc":"Takes an RRule string, a start date, an end date and a boolean indicating whether to include the\nstart date in the results. Returns a list of strings representing the occurrences that fall between\nthe start and end dates.","ref":"ExDateUtil.Rrule.html#between/4"},{"type":"function","title":"Arguments: - ExDateUtil.Rrule.between/4","doc":"* `rrule`: The RRule string to parse.\n* `start_date`: The start date of the range to check for occurrences.\n* `end_date`: The end date of the occurrences.\n* `inc`: Whether to include the start date in the results.","ref":"ExDateUtil.Rrule.html#between/4-arguments"},{"type":"function","title":"Returns: - ExDateUtil.Rrule.between/4","doc":"A list of strings","ref":"ExDateUtil.Rrule.html#between/4-returns"},{"type":"function","title":"Example - ExDateUtil.Rrule.between/4","doc":"iex> ExDateUtil.Rrule.between(\"DTSTART;TZID=Europe/London:20230326T000000Z\\nRRULE:FREQ=DAILY;BYDAY=Mo,Tu,We\", \"2023-03-26T00:00:00.000+01:00\", \"2023-03-29T00:00:00.000+01:00\", false)\n    [\"2023-03-27T00:00:00.000+01:00\", \"2023-03-28T00:00:00.000+01:00\"]\n\n    iex> ExDateUtil.Rrule.between(\"DTSTART;TZID=Europe/London:20230326T000000Z\\nRRULE:FREQ=DAILY;BYDAY=Mo,Tu,We\", \"2023-03-26T00:00:00.000+01:00\", \"2023-03-29T00:00:00.000+01:00\", true)\n    [\"2023-03-27T00:00:00.000+01:00\", \"2023-03-28T00:00:00.000+01:00\", \"2023-03-29T00:00:00.000+01:00\"]","ref":"ExDateUtil.Rrule.html#between/4-example"},{"type":"function","title":"ExDateUtil.Rrule.just_after/3","doc":"Takes an RRule string, an after_date string, and a boolean indicating whether to include the\nstart date in the results. Returns a list of date strings representing the occurrence that\nhappens just after the given date.","ref":"ExDateUtil.Rrule.html#just_after/3"},{"type":"function","title":"Arguments: - ExDateUtil.Rrule.just_after/3","doc":"* `rrule`: The RRule string to parse.\n* `after_date`: The date to start looking for occurrences after.\n* `inc`: If true, include the start date in the results.","ref":"ExDateUtil.Rrule.html#just_after/3-arguments"},{"type":"function","title":"Returns: - ExDateUtil.Rrule.just_after/3","doc":"A list of strings.","ref":"ExDateUtil.Rrule.html#just_after/3-returns"},{"type":"function","title":"Example - ExDateUtil.Rrule.just_after/3","doc":"iex> ExDateUtil.Rrule.just_after(\"DTSTART;TZID=Europe/London:20230326T000000Z\\nRRULE:FREQ=DAILY;BYDAY=Mo,Tu,We\", \"2023-03-29T00:00:00.000+01:00\", false)\n    [\"2023-04-03T00:00:00.000+01:00\"]\n\n    iex> ExDateUtil.Rrule.just_after(\"DTSTART;TZID=Europe/London:20230326T000000Z\\nRRULE:FREQ=DAILY;BYDAY=Mo,Tu,We\", \"2023-03-29T00:00:00.000+01:00\", true)\n    [\"2023-03-29T00:00:00.000+01:00\"]","ref":"ExDateUtil.Rrule.html#just_after/3-example"},{"type":"function","title":"ExDateUtil.Rrule.just_before/3","doc":"Takes an RRule string, a date string, and a boolean indicating whether to include the\nbefore date in the results. Returns a list of date strings representing the occurrence\nthat happens just before the given date.","ref":"ExDateUtil.Rrule.html#just_before/3"},{"type":"function","title":"Arguments: - ExDateUtil.Rrule.just_before/3","doc":"* `rrule`: The RRule string to parse.\n* `before`: The date to find the occurrence before.\n* `inc`: If true, the before date will be included in the results.","ref":"ExDateUtil.Rrule.html#just_before/3-arguments"},{"type":"function","title":"Returns: - ExDateUtil.Rrule.just_before/3","doc":"A list of strings.","ref":"ExDateUtil.Rrule.html#just_before/3-returns"},{"type":"function","title":"Example - ExDateUtil.Rrule.just_before/3","doc":"iex> ExDateUtil.Rrule.just_before(\"DTSTART;TZID=Europe/London:20230326T000000Z\\nRRULE:FREQ=DAILY;BYDAY=Mo,Tu,We\", \"2023-03-29T00:00:00.000+01:00\", false)\n    [\"2023-03-28T00:00:00.000+01:00\"]\n\n    iex> ExDateUtil.Rrule.just_before(\"DTSTART;TZID=Europe/London:20230326T000000Z\\nRRULE:FREQ=DAILY;BYDAY=Mo,Tu,We\", \"2023-03-29T00:00:00.000+01:00\", true)\n    [\"2023-03-29T00:00:00.000+01:00\"]","ref":"ExDateUtil.Rrule.html#just_before/3-example"},{"type":"function","title":"ExDateUtil.Rrule.next/2","doc":"Takes an RRule string and a limit integer. Returns a list of strings\nthat represent the next `limit` number of occurrences.","ref":"ExDateUtil.Rrule.html#next/2"},{"type":"function","title":"Arguments: - ExDateUtil.Rrule.next/2","doc":"* `rrule`: The RRule string to parse.\n* `limit`: The number of recurrences to return.","ref":"ExDateUtil.Rrule.html#next/2-arguments"},{"type":"function","title":"Returns: - ExDateUtil.Rrule.next/2","doc":"A list of strings.","ref":"ExDateUtil.Rrule.html#next/2-returns"},{"type":"function","title":"Example - ExDateUtil.Rrule.next/2","doc":"iex> ExDateUtil.Rrule.next(\"DTSTART;TZID=Europe/London:20230326T000000Z\\nRRULE:FREQ=DAILY;BYDAY=Mo,Tu,We\", 2)\n    [\"2023-03-27T00:00:00.000+01:00\", \"2023-03-28T00:00:00.000+01:00\"]","ref":"ExDateUtil.Rrule.html#next/2-example"},{"type":"function","title":"ExDateUtil.Rrule.properties/1","doc":"Takes an RRule string and returns a map of the properties.","ref":"ExDateUtil.Rrule.html#properties/1"},{"type":"function","title":"Arguments: - ExDateUtil.Rrule.properties/1","doc":"* `rrule`: The RRule string to parse.","ref":"ExDateUtil.Rrule.html#properties/1-arguments"},{"type":"function","title":"Returns: - ExDateUtil.Rrule.properties/1","doc":"A map of the RRule's properties.","ref":"ExDateUtil.Rrule.html#properties/1-returns"},{"type":"function","title":"Example - ExDateUtil.Rrule.properties/1","doc":"iex> ExDateUtil.Rrule.properties(\"DTSTART;TZID=Europe/London:20230326T000000Z\\nRRULE:FREQ=DAILY;BYDAY=Mo,Tu,We\")\n    %{\n      count: \"None\",\n      until: \"None\",\n      __struct__: Properties,\n      interval: 1,\n      freq: \"Daily\",\n      week_start: \"Mon\",\n      by_set_pos: \"[]\",\n      by_month: [],\n      by_month_day: [],\n      by_n_month_day: \"[]\",\n      by_year_day: [],\n      by_week_no: [],\n      by_weekday: [\"Every(Mon)\", \"Every(Tue)\", \"Every(Wed)\"],\n      by_hour: [0],\n      by_minute: [0],\n      by_second: [0],\n      by_easter: \"None\"\n    }","ref":"ExDateUtil.Rrule.html#properties/1-example"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}